<?php

//Posts Slider shortcode

if ( function_exists( 'vc_map' ) ) {
	$url = EF_URL . '/admin/assets/images/shortcodes_images/posts_list/';
	vc_map(
		array(
			'name'     => __( 'Posts List', 'js_composer' ),
			'base'     => 'phoxy_posts_list',
			'category' => __( 'Content', 'js_composer' ),
			'params'   => array(
				array(
					'type'       => 'select_preview',
					'param_name' => 'style',
					'heading'    => esc_html__( 'Style', 'js_composer' ),
					'value'      => array(
						array(
							'value' => 'modern_columns',
							'label' => esc_html__( 'Modern Columns', 'js_composer' ),
							'image' => $url . 'modern_columns.jpg'
						),
						array(
							'value' => 'parallax',
							'label' => esc_html__( 'Parallax', 'js_composer' ),
							'image' => $url . 'parallax.jpg'
						),
					),
				),
				array(
					'type'        => 'vc_efa_chosen',
					'heading'     => __( 'Select Categories', 'js_composer' ),
					'param_name'  => 'cats',
					'placeholder' => __( 'Select category', 'js_composer' ),
					'value'       => phoxy_element_values( 'categories', array(
						'sort_order' => 'ASC',
						'taxonomy'   => 'category',
						'hide_empty' => false,
					) ),
					'std'         => '',
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Order by', 'js_composer' ),
					'param_name'  => 'orderby',
					'value'       => array(
						'',
						__( 'Date', 'js_composer' )          => 'date',
						__( 'ID', 'js_composer' )            => 'ID',
						__( 'Author', 'js_composer' )        => 'author',
						__( 'Title', 'js_composer' )         => 'title',
						__( 'Modified', 'js_composer' )      => 'modified',
						__( 'Random', 'js_composer' )        => 'rand',
						__( 'Comment count', 'js_composer' ) => 'comment_count'
					),
					'description' => sprintf( __( 'Select how to sort retrieved posts. More at %s.', 'js_composer' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' )
				),
				array(
					'type'        => 'dropdown',
					'heading'     => __( 'Sort order', 'js_composer' ),
					'param_name'  => 'order',
					'value'       => array(
						__( 'Descending', 'js_composer' ) => 'DESC',
						__( 'Ascending', 'js_composer' )  => 'ASC',
					),
					'description' => sprintf( __( 'Select ascending or descending order. More at %s.', 'js_composer' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' )
				),
				array(
					'type'       => 'textfield',
					'heading'    => __( 'Count items', 'js_composer' ),
					'param_name' => 'count',
				),
			)
		)
	);
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
	class WPBakeryShortCode_phoxy_posts_list extends WPBakeryShortCode {
		protected function content( $atts, $content = null ) {
			extract( shortcode_atts( array(
				'cats'                 => '',
				'count'                => '',
				'style'                => 'modern_columns',
				'orderby'              => '',
				'order'                => 'date',
			), $atts ) );


			// include needed stylesheets
			if ( ! in_array( "phoxy-posts-list-style", self::$css_scripts ) ) {
				self::$css_scripts[] = "phoxy-posts-list-style";
			}
			$this->enqueueCss();


			$style = isset($style) && !empty($style) ? $style : 'modern_columns';

			if ( ! in_array( "stellar", self::$js_scripts ) && $style == 'parallax') {
				self::$js_scripts[] = "stellar";
			}

			if ( ! in_array( "post-list", self::$js_scripts ) && $style == 'parallax') {
				self::$js_scripts[] = "post-list";
			}

			$this->enqueueJs();

			// base args
			$args = array(
				'post_type'      => 'post',
				'posts_per_page' => ( ! empty( $count ) && is_numeric( $count ) ) ? $count : 9,
			);

			// Order posts
			if ( null !== $orderby ) {
				$args['orderby'] = $orderby;
			}
			$args['order'] = $order;

			// category
			if ( ! empty( $cats ) ) {
				$term_slugs        = explode( ',', $cats );
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'category',
						'field'    => 'slug',
						'terms'    => $term_slugs,
					)
				);
			}

			ob_start();

			$posts = new WP_Query( $args );

			if ( $posts->have_posts() ) { ?>

				<div class="posts-list-wrap <?php echo esc_attr( $style ); ?>">
					<?php if ( $style == 'modern_columns' ) { ?>

						<?php while ( $posts->have_posts() ) :
							$posts->the_post();

							$category_items = '';
							$categories               = get_the_category();
							if ( $categories ) {
								foreach ( $categories as $category ) {

									$category_items .= '<span>' . trim( $category->name ) . '</span>';
								}
							}

							$image_id        = get_post_thumbnail_id( $posts->ID );
							$alt       = get_post_meta($image_id, '_wp_attachment_image_alt', true );
							$image           = ( is_numeric( $image_id ) && ! empty( $image_id ) ) ? wp_get_attachment_image_url( $image_id, 'full' ) : ''; ?>

							<a href="<?php the_permalink(); ?>" class="post-item" target="_self">
								<span class="content">
									<span class="info-top">
										<span class="category"><?php echo $category_items; ?></span>
									</span>
									<span class="title">
										<?php the_title(); ?>
									</span>
									<span class="info-bottom">
										<span class="date"><?php the_time( get_option( 'date_format' ) ); ?></span>
									</span>
								</span>
								<span class="img-wrap">
									<?php echo phoxy_the_lazy_load_flter( $image, array(
										'class' => 's-img-switch',
										'alt' => $alt
									) ); ?>
								</span>
							</a>


						<?php endwhile;


						wp_reset_postdata(); ?>


					<?php }
					elseif( $style == 'parallax'){ ?>

						<?php while ( $posts->have_posts() ) :
							$posts->the_post();

							$category_items = '';
							$categories               = get_the_category();
							if ( $categories ) {
								foreach ( $categories as $category ) {

									$category_items .= '<span>' . trim( $category->name ) . '</span>';
								}
							}

							$image_id        = get_post_thumbnail_id( $posts->ID );
							$alt       = get_post_meta($image_id, '_wp_attachment_image_alt', true );
							$image           = ( is_numeric( $image_id ) && ! empty( $image_id ) ) ? wp_get_attachment_image_url( $image_id, 'full' ) : ''; ?>

                            <div class="post-item image-wrap stellar-parallax" data-stellar-background-ratio="0.5">
	                            <?php echo phoxy_the_lazy_load_flter( $image, array(
		                            'class' => 's-img-switch',
		                            'alt' => $alt
	                            ) ); ?>
								<div class="content">
									<div class="info-top">
										<span class="category"><?php echo $category_items; ?></span>
									</div>
									<a href="<?php the_permalink(); ?>" class="title" target="_self">
										<?php the_title(); ?>
									</a>
									<div class="info-bottom">
										<div class="date"><?php the_time( get_option( 'date_format' ) ); ?></div>
									</div>
								</div>
                            </div>


						<?php endwhile;


						wp_reset_postdata(); ?>

                    <?php } ?>

				</div>

			<?php }

			return ob_get_clean();
		}

	}
}


