<?php
/**
 * The template for requried actions hooks.
 *
 * @package phoxy
 * @since 1.0
 */

add_action( 'wp_enqueue_scripts', 'phoxy_enqueue_scripts' );
add_action( 'wp_footer', 'phoxy_enqueue_main_style' );
add_action( 'widgets_init', 'phoxy_register_widgets' );
add_action( 'tgmpa_register', 'phoxy_include_required_plugins' );


define( 'CS_ACTIVE_FRAMEWORK', true );
define( 'CS_ACTIVE_METABOX', true );
define( 'CS_ACTIVE_TAXONOMY', true );
define( 'CS_ACTIVE_SHORTCODE', false );
define( 'CS_ACTIVE_CUSTOMIZE', false );


/*
 * Register sidebar.
 */
if ( ! function_exists( 'phoxy_register_widgets' ) ) {
	function phoxy_register_widgets() {
		// register sidebars
		register_sidebar(
			array(
				'id'            => 'sidebar',
				'name'          => esc_html__( 'Sidebar', 'phoxy' ),
				'before_widget' => '<div id="%1$s" class="sidebar-item %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5>',
				'after_title'   => '</h5>',
				'description'   => esc_html__( 'Drag the widgets for sidebars.', 'phoxy' )
			)
		);

        if( function_exists( 'cs_framework_init' ) ){
            register_sidebar(
                array(
                    'id'            => 'shop',
                    'name'          => esc_html__( 'Shop Sidebar', 'phoxy' ),
                    'before_widget' => '<div id="%1$s" class="sidebar-item %2$s">',
                    'after_widget'  => '</div>',
                    'before_title'  => '<h5>',
                    'after_title'   => '</h5>',
                    'description'   => esc_html__( 'Drag the widgets for sidebars.', 'phoxy' )
                )
            );
        }
	}
}

function phoxy_enqueue_main_style() {

	if ( is_page() || is_home() ) {
		$post_id = get_queried_object_id();
	} else {
		$post_id = get_the_ID();
	}

	wp_enqueue_style( 'phoxy-dynamic', admin_url( 'admin-ajax.php' ) . '?action=phoxy_dynamic_css&post=' . $post_id, array( 'phoxy-theme' ) );
}


/* For Woocommerce */
if ( ! function_exists( 'phoxy_add_to_cart_fragment' ) ) {
	function phoxy_add_to_cart_fragment( $fragments ) {

		ob_start();
		$count = WC()->cart->cart_contents_count;
		?>
        <a class="phoxy-shop-icon ion-bag" href="<?php echo WC()->cart->get_cart_url(); ?>"
           title="<?php esc_attr_e( 'View your shopping cart', 'phoxy' ); ?>">
			<?php if ( $count > 0 ) { ?>
                <div class="cart-contents">
                    <span class="cart-contents-count"><?php echo esc_html( $count ); ?></span>
                </div>
			<?php } ?>
        </a>
		<?php $fragments['a.phoxy-shop-icon'] = ob_get_clean();

		$fragments['div.phoxy_mini_cart'] = phoxy_mini_cart();

		return $fragments;
	}
}
add_filter( 'woocommerce_add_to_cart_fragments', 'phoxy_add_to_cart_fragment' );

/*
Register Fonts
*/
if ( ! function_exists( 'phoxy_fonts_url' ) ) {
	function phoxy_fonts_url() {
		$font_url = '';

		/*
		Translators: If there are characters in your language that are not supported
		by chosen font(s), translate this to 'off'. Do not translate into your own language.
		 */
		if ( 'off' !== esc_html_x( 'on', 'Google font: on or off', 'phoxy' ) ) {
			$fonts = array(
				'Source Sans Pro:400,400i,600,600i,700'
			);

			$font_url = add_query_arg( 'family',
				urlencode( implode( '|', $fonts ) . "&subset=latin,latin-ext" ), "//fonts.googleapis.com/css" );
		}

		return $font_url;
	}
}
/*
Enqueue scripts and styles.
*/
if ( ! function_exists( 'phoxy_font_scripts' ) ) {
	function phoxy_font_scripts() {
		wp_enqueue_style( 'phoxy-fonts', phoxy_fonts_url(), array(), '1.0.0' );
	}
}

/**
 * @ return null
 * @ param none
 * @ loads all the js and css script to frontend
 **/
if ( ! function_exists( 'phoxy_enqueue_scripts' ) ) {
	function phoxy_enqueue_scripts() {

		// general settings
		if ( ( is_admin() ) ) {
			return;
		}

		if( is_page() || is_home()) {
			$post_id = get_queried_object_id();
		} else {
			$post_id = get_the_ID();
		}

		$preloader_type = (cs_get_option( 'preloader_type' ) && cs_get_option( 'preloader_type' ) == 'image') || ! function_exists( 'cs_framework_init' ) ? true : false;
		$meta_data = get_post_meta( $post_id, '_custom_page_options', true );
		$whizzy_meta = get_post_meta($post_id, 'phoxy_whizzy_options', true);

		$bg_slider = cs_get_option('bg_slider');
		$bg_slider = isset($meta_data['bg_slider']) && !empty($meta_data['bg_slider']) ? $meta_data['bg_slider'] : $bg_slider;
		$bg_slider = isset($whizzy_meta['bg_slider']) && !empty($whizzy_meta['bg_slider']) ? $whizzy_meta['bg_slider'] : $bg_slider;

		$bg_slider_images = cs_get_option('bg_slider_images');
		$bg_slider_images = isset($meta_data['bg_slider_images']) && !empty($meta_data['bg_slider_images']) ? $meta_data['bg_slider_images'] : $bg_slider_images;
		$bg_slider_images = isset($whizzy_meta['bg_slider_images']) && !empty($whizzy_meta['bg_slider_images']) ? $whizzy_meta['bg_slider_images'] : $bg_slider_images;


		wp_enqueue_style( 'phoxy-fonts', phoxy_fonts_url(), array(), '1.0.0' );
		wp_enqueue_script( 'modernizr', PHOXY_T_URI . '/assets/js/lib/modernizr-2.6.2.min.js', array( 'jquery' ), '', false );
		if($preloader_type){
			wp_enqueue_script( 'animsition', PHOXY_T_URI . '/assets/js/lib/animsition.js', array( 'jquery' ), '', false );
		}
		if($bg_slider && !empty($bg_slider_images)){
			wp_enqueue_script( 'phoxy-gridrotator', PHOXY_T_URI . '/assets/js/lib/jquery.gridrotator.js', array( 'jquery' ), '', false );
        }
		wp_enqueue_script( 'parallax', PHOXY_T_URI . '/assets/js/lib/parallax.js', array( 'jquery' ), '', false );
		wp_enqueue_script( 'isotope', PHOXY_T_URI . '/assets/js/lib/isotope.js', array( 'jquery' ), '', false );
		wp_enqueue_script( 'countdown', PHOXY_T_URI . '/assets/js/jquery.countdown.min.js', '', '', true );
		wp_enqueue_script( 'phoxy-foxlazy', PHOXY_T_URI . '/assets/js/foxlazy.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'easings', PHOXY_T_URI . '/assets/js/jquery.easings.min.js', '', '', true );
		wp_enqueue_script( 'multiscroll', PHOXY_T_URI . '/assets/js/jquery.multiscroll.min.js', '', '', true );
		wp_enqueue_script( 'magnific', PHOXY_T_URI . '/assets/js/magnific.js', '', '', true );
		wp_enqueue_script( 'cloudflare', PHOXY_T_URI . '/assets/js/TweenMax.min.js', '', '', true );
		wp_enqueue_script( 'equal-heights-plugin', PHOXY_T_URI . '/assets/js/equalHeightsPlugin.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'fitvids', PHOXY_T_URI . '/assets/js/jquery.fitvids.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'swiper', PHOXY_T_URI . '/assets/js/swiper.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'scrollMonitor', PHOXY_T_URI . '/assets/js/scrollMonitor.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'phoxy-slider-transition-init', PHOXY_T_URI . '/assets/js/slider-transition.js', array( 'jquery', 'imagesloaded' ), '', true );

		if ( ! function_exists( 'cs_framework_init' ) ) {
			wp_enqueue_script( 'mousewheel', PHOXY_T_URI . '/assets/lib/js/jquery.mousewheel.min.js', array( 'jquery' ), '', true );
			wp_enqueue_script( 'lightgallery', PHOXY_T_URI . '/assets/lib/js/lightgallery.min.js', array( 'jquery' ), '', true );
			wp_enqueue_script( 'justified-gallery', PHOXY_T_URI . '/assets/lib/js/jquery.justifiedGallery.js', array( 'jquery' ), '', true );
		}

		wp_enqueue_script( 'phoxy-slick', PHOXY_T_URI . '/assets/js/slick.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'thumbnails-popup', PHOXY_T_URI . '/assets/js/lib/thumbnails-popup.js', array(
			'jquery',
			'dgwt-jg-lightgallery'
		), '', true );
		wp_enqueue_script( 'phoxy-pixi', PHOXY_T_URI . '/assets/js/pixi.min.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'phoxy-main', PHOXY_T_URI . '/assets/js/script.js', array( 'jquery' ), '', true );

		// add TinyMCE style
		add_editor_style();

		// including jQuery plugins
		wp_localize_script( 'jquery', 'get',
			array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'siteurl' => get_template_directory_uri(),
			)
		);

		if ( is_singular() ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// register style
		wp_enqueue_style( 'phoxy-base', PHOXY_T_URI . '/style.css' );

		wp_enqueue_style( 'magnific-popup', PHOXY_T_URI . '/assets/css/magnific-popup.css' );
		if($preloader_type) {
			wp_enqueue_style( 'animsition', PHOXY_T_URI . '/assets/css/animsition.min.css' );
		}
		wp_enqueue_style( 'bootstrap', PHOXY_T_URI . '/assets/css/bootstrap.min.css' );
		wp_enqueue_style( 'font-awesome', PHOXY_T_URI . '/assets/css/font-awesome.min.css' );
		wp_enqueue_style( 'swiper', PHOXY_T_URI . '/assets/css/swiper.css' );
		wp_enqueue_style( 'simple-fonts', PHOXY_T_URI . '/assets/css/simple-line-icons.css' );
		wp_enqueue_style( 'ionicons', PHOXY_T_URI . '/assets/css/ionicons.min.css' );
		wp_enqueue_style( 'phoxy-slick', PHOXY_T_URI . '/assets/css/slick.css' );
		wp_enqueue_style( 'phoxy-portfolio', PHOXY_T_URI . '/assets/css/portfolio.css' );
		wp_enqueue_style( 'phoxy-blog', PHOXY_T_URI . '/assets/css/blog.css' );
		wp_enqueue_style( 'phoxy-shop', PHOXY_T_URI . '/assets/css/shop.css' );
		if ( ! function_exists( 'cs_framework_init' ) ) {
			wp_enqueue_style( 'admin-style', PHOXY_T_URI . '/assets/lib/css/admin-style.css' );
			wp_enqueue_style( 'lightgallery', PHOXY_T_URI . '/assets/lib/css/lightgallery.min.css' );
			wp_enqueue_style( 'libs-style', PHOXY_T_URI . '/assets/lib/css/style.css' );
		}

		wp_enqueue_style( 'phoxy-theme', PHOXY_T_URI . '/assets/css/style.css' );

		/* Add Custom JS */
		if ( cs_get_option( 'custom_js_scripts' ) ) {
			wp_add_inline_script( 'phoxy-main', cs_get_option( 'custom_js_scripts' ) );
		}

		if ( cs_get_option( 'enable_lazy_load' ) ) {
			wp_localize_script( 'phoxy-main', 'enable_foxlazy', 'enable' );
		}

		if ( cs_get_option( 'heading' ) ) {
			foreach ( cs_get_option( 'heading' ) as $key => $title ) {
				if ( empty( $title['heading_family'] ) ) {
					continue;
				}
				$font_family = $title['heading_family'];
				if ( ! empty( $font_family['family'] ) ) {
					wp_enqueue_style( sanitize_title_with_dashes( $font_family['family'] ), '//fonts.googleapis.com/css?family=' . $font_family['family'] . ':' . $title['heading_family']['variant'] . '' );
				}
			}
		}

		// include font family
		if ( function_exists( 'phoxy_include_fonts' ) ) {
			phoxy_include_fonts(
				array(
					'menu_item_family',
					'submenu_item_family',
					'gallery_font_family',
					'all_button_font_family',
					'all_button_font_family',
					'footer_font_family',
					'item_gallery_font_family',
				) // all options name
			);
		}

	}
}


function phoxy_regiser_info_icons() {
	wp_enqueue_style( 'phoxy-font-info', PHOXY_T_URI . '/assets/css/simple-line-icons.css' );
}

add_action( 'vc_base_register_admin_css', 'phoxy_regiser_info_icons' );

/**
 * Include plugins
 **/
if ( ! function_exists( 'phoxy_include_required_plugins' ) ) {
	function phoxy_include_required_plugins() {

		$plugins = array(
			array(
				'name'               => esc_html__( 'Phoxy Plugins', 'phoxy' ),
				// The plugin name
				'slug'               => 'phoxy-plugins',
				// The plugin slug (typically the folder name)
				'source'             => esc_url( 'http://download-plugins.viewdemo.co/phoxy/phoxy-plugins.zip' ),
				// The plugin source
				'required'           => true,
				// If false, the plugin is only 'recommended' instead of required
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'version'            => '',
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'WPBakery Page Builder', 'phoxy' ),
				// The plugin name
				'slug'               => 'js_composer',
				// The plugin slug (typically the folder name)
				'source'             => esc_url( 'http://download-plugins.viewdemo.co/premium-plugins/js_composer.zip' ),
				// The plugin source
				'required'           => true,
				// If false, the plugin is only 'recommended' instead of required
				'version'            => '',
				// E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'Whizzy', 'phoxy' ),
				// The plugin name
				'slug'               => 'whizzy',
				// The plugin slug (typically the folder name)
				'required'           => true,
				// If false, the plugin is only 'recommended' instead of required
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'version'            => '',
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'Booked Appointments', 'phoxy' ),
				// The plugin name
				'slug'               => 'booked',
				// The plugin slug (typically the folder name)
				'source'             => esc_url( 'http://download-plugins.viewdemo.co/premium-plugins/booked.zip' ),
				// The plugin source
				'required'           => false,
				// If false, the plugin is only 'recommended' instead of required
				'version'            => '',
				// E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'The Grid', 'phoxy' ),
				// The plugin name
				'slug'               => 'the_grid',
				// The plugin slug (typically the folder name)
				'source'             => esc_url( 'http://download-plugins.viewdemo.co/premium-plugins/the_grid.zip' ),
				// The plugin source
				'required'           => true,
				// If false, the plugin is only 'recommended' instead of required
				'version'            => '',
				// E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'Contact Form 7', 'phoxy' ),
				// The plugin name
				'slug'               => 'contact-form-7',
				// The plugin slug (typically the folder name)
				'required'           => false,
				// If false, the plugin is only 'recommended' instead of required
				'version'            => '',
				// E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'UpQode Google Maps', 'phoxy' ),
				// The plugin name
				'slug'               => 'upqode-google-maps',
				// The plugin slug (typically the folder name)
				'required'           => false,
				// If false, the plugin is only 'recommended' instead of required
				'version'            => '',
				// E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'WooCommerce', 'phoxy' ),
				// The plugin name
				'slug'               => 'woocommerce',
				// The plugin slug (typically the folder name)
				'required'           => false,
				// If false, the plugin is only 'recommended' instead of required
				'version'            => '',
				// E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__( 'Ultimate GDPR', 'phoxy' ),
				// The plugin name
				'slug'               => 'ct-ultimate-gdpr',
				// The plugin slug (typically the folder name)
				'source'             => esc_url( 'http://download-plugins.viewdemo.co/premium-plugins/ct-ultimate-gdpr.zip' ),
				// The plugin source
				'required'           => true,
				// If false, the plugin is only 'recommended' instead of required
				'version'            => '',
				// E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false,
				// If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false,
				// If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '',
				// If set, overrides default API URL and points to an external URL
			),
			array(
				'name'               => esc_html__('Gutenberg Blocks Collection', 'phoxy'), // The plugin name
				'slug'               => 'qodeblock', // The plugin slug (typically the folder name)
				'required'           => true, // If false, the plugin is only 'recommended' instead of required
				'version'            => '', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
				'external_url'       => '', // If set, overrides default API URL and points to an external URL
			),
		);

		// Change this to your theme text domain, used for internationalising strings

		/**
		 * Array of configuration settings. Amend each line as needed.
		 * If you want the default strings to be available under your own theme domain,
		 * leave the strings uncommented.
		 * Some of the strings are added into a sprintf, so see the comments at the
		 * end of each line for what each argument will be.
		 */
		$config = array(
			'domain'       => 'phoxy',                    // Text domain - likely want to be the same as your theme.
			'default_path' => '',                            // Default absolute path to pre-packaged plugins
			'menu'         => 'tgmpa-install-plugins',    // Menu slug
			'has_notices'  => true,                        // Show admin notices or not
			'is_automatic' => true,                        // Automatically activate plugins after installation or not
			'message'      => '',                            // Message to output right before the plugins table
			'strings'      => array(
				'page_title'                      => esc_html__( 'Install Required Plugins', 'phoxy' ),
				'menu_title'                      => esc_html__( 'Install Plugins', 'phoxy' ),
				'installing'                      => esc_html__( 'Installing Plugin: %s', 'phoxy' ),
				// %1$s = plugin name
				'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'phoxy' ),
				'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'phoxy' ),
				// %1$s = plugin name(s)
				'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'phoxy' ),
				// %1$s = plugin name(s)
				'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'phoxy' ),
				// %1$s = plugin name(s)
				'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'phoxy' ),
				// %1$s = plugin name(s)
				'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'phoxy' ),
				// %1$s = plugin name(s)
				'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'phoxy' ),
				// %1$s = plugin name(s)
				'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'phoxy' ),
				// %1$s = plugin name(s)
				'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'phoxy' ),
				// %1$s = plugin name(s)
				'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'phoxy' ),
				'activate_link'                   => _n_noop( 'Activate installed plugin', 'Activate installed plugins', 'phoxy' ),
				'return'                          => esc_html__( 'Return to Required Plugins Installer', 'phoxy' ),
				'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'phoxy' ),
				'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'phoxy' ),
				// %1$s = dashboard link
				'nag_type'                        => 'updated'
				// Determines admin notice type - can only be 'updated' or 'error'
			)
		);

		tgmpa( $plugins, $config );
	}
}

if ( ! function_exists( 'phoxy_password_form' ) ) {
	function phoxy_password_form($post_id) {
		$label = 'pwbox-' . ( empty( $post_id ) ? rand() : $post_id );
		$o     = '<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">
  ' . esc_html__( 'ENTER PASSWORD BELOW:', 'phoxy' ) . '
  <label for="' . esc_attr( $label ) . '"></label><input placeholder="' . esc_attr__( "Password:", 'phoxy' ) . '" name="post_password" id="' . esc_attr( $label ) . '" type="password" size="20" maxlength="20" /><input type="submit" name="' . __( 'Submit', 'phoxy' ) . '" value="' . __( 'ACCEPT', 'phoxy' ) . '" />
  </form>
  ';

		return $o;
	}
}
add_filter( 'the_password_form', 'phoxy_password_form' );


if ( ! function_exists( 'phoxy_redirect_coming_soon' ) ) {
	function phoxy_redirect_coming_soon() {
		if ( cs_get_option( 'phoxy_enable_coming_soon' ) && cs_get_option( 'phoxy_page_coming_soon' ) && ! is_admin_bar_showing() ) {

			$redirect_permalink = get_permalink( cs_get_option( 'phoxy_page_coming_soon' ) );
			if ( get_permalink() != $redirect_permalink ) {
				wp_redirect( get_permalink( cs_get_option( 'phoxy_page_coming_soon' ) ) );
				exit();
			}
		}
	}
}
add_action( 'template_redirect', 'phoxy_redirect_coming_soon' );


/*
 * Check need minimal requirements (PHP and WordPress version)
 */
if ( version_compare( $GLOBALS['wp_version'], '4.3', '<' ) || version_compare( PHP_VERSION, '5.3', '<' ) ) {
	if ( ! function_exists( 'phoxy_requirements_notice' ) ) {
		function phoxy_requirements_notice() {
			$message = sprintf( esc_html__( 'Phoxy theme needs minimal WordPress version 4.3 and PHP 5.3<br>You are running version WordPress - %s, PHP - %s.<br>Please upgrade need module and try again.', 'phoxy' ), $GLOBALS['wp_version'], PHP_VERSION );
			printf( '<div class="notice-warning notice"><p><strong>%s</strong></p></div>', $message );
		}
	}
	add_action( 'admin_notices', 'phoxy_requirements_notice' );
}


/*
 * Check need minimal requirements (PHP and WordPress version)
 */
if ( ! function_exists( 'phoxy_coming_soon_notice' ) ) {
	function phoxy_coming_soon_notice() {
		if ( cs_get_option( 'phoxy_enable_coming_soon' ) ) {
			?>
            <div class="notice-warning notice">
                <p><strong>
						<?php echo esc_html__( 'Your "Coming Soon" option is enabled now.', 'phoxy' );
						?></strong></p></div>
			<?php
		}
	}
}
add_action( 'admin_notices', 'phoxy_coming_soon_notice' );


/*
 * Add backend styles for Gutenberg.
 */
add_action( 'enqueue_block_editor_assets', 'phoxy_add_gutenberg_assets' );

function phoxy_add_gutenberg_assets() {
	// Load the theme styles within Gutenberg.
	wp_enqueue_style( 'phoxy-gutenberg', get_theme_file_uri( '/assets/css/gutenberg-editor-style.css' ), false );
	wp_enqueue_style( 'font-awesome',  get_theme_file_uri( '/assets/css/font-awesome.min.css' ), false );
	wp_enqueue_style( 'ionicons',  get_theme_file_uri( '/assets/css/ionicons.min.css' ), false );
}
